# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`gitlabrunner`](#gitlabrunner): Install and configure gitlan ci runners.
* [`gitlabrunner::helper::docker`](#gitlabrunner--helper--docker): Install Docker CE
* [`gitlabrunner::helper::shell`](#gitlabrunner--helper--shell): Install Vagrant, Virtualbox used with shell executor for acceptance tests of Puppet modules.

#### Private Classes

* `gitlabrunner::config::global`: Modify global section in runner's configuration file /etc/gitlab-runner/config.toml
* `gitlabrunner::install`: Install gitlab runner.

### Defined types

* [`gitlabrunner::register`](#gitlabrunner--register): Register a runner to a gitlab-ci coordinator
* [`gitlabrunner::unregister`](#gitlabrunner--unregister): To unregister a runner from a gitlab-ci coordinator

### Data types

* [`Gitlabrunner::Settings`](#Gitlabrunner--Settings): Settings available for a runner

## Classes

### <a name="gitlabrunner"></a>`gitlabrunner`

Specifies what state the gitlab-runner package should be in.
Name of debian package name for gitlab-runner
Specifies a GPG key to authenticate Apt package signatures.
Specifies the location of an existing GPG key file to install.

#### Examples

##### 

```puppet
class { 'gitlabrunner' :
  concurrent                  => 4,
  dockerhelper_install_docker => true,
  runners                     => {
    'runner01' => {
      authentication-token => 'get.secret.from.gitlab.webui',
      url                  => 'https://mygitlabinstance.foo.org',
      executor             => 'docker',
      executor-options     => {
        docker-image   => 'ruby:3.0',
        docker-volumes => '/var/run/docker.sock:/var/run/docker.sock',
      }
    }
  }
}
```

#### Parameters

The following parameters are available in the `gitlabrunner` class:

* [`runners`](#-gitlabrunner--runners)
* [`ensure`](#-gitlabrunner--ensure)
* [`package_name`](#-gitlabrunner--package_name)
* [`repository_key_id`](#-gitlabrunner--repository_key_id)
* [`repository_key_url`](#-gitlabrunner--repository_key_url)
* [`concurrent`](#-gitlabrunner--concurrent)
* [`check_resolver`](#-gitlabrunner--check_resolver)
* [`dockerhelper_install_docker`](#-gitlabrunner--dockerhelper_install_docker)
* [`dockerhelper_enable_usernamespace`](#-gitlabrunner--dockerhelper_enable_usernamespace)
* [`dockerhelper_enable_ipv6`](#-gitlabrunner--dockerhelper_enable_ipv6)
* [`dockerhelper_ipv6_cidr`](#-gitlabrunner--dockerhelper_ipv6_cidr)
* [`dockerhelper_prune_weekday`](#-gitlabrunner--dockerhelper_prune_weekday)
* [`dockerhelper_prune_hour`](#-gitlabrunner--dockerhelper_prune_hour)
* [`shellhelper_install_ruby`](#-gitlabrunner--shellhelper_install_ruby)
* [`shellhelper_install_vagrant`](#-gitlabrunner--shellhelper_install_vagrant)
* [`shellhelper_install_virtualbox`](#-gitlabrunner--shellhelper_install_virtualbox)
* [`shellhelper_vagrant_package_name`](#-gitlabrunner--shellhelper_vagrant_package_name)
* [`shellhelper_vagrant_package_version`](#-gitlabrunner--shellhelper_vagrant_package_version)
* [`shellhelper_vagrant_repository_key_id`](#-gitlabrunner--shellhelper_vagrant_repository_key_id)
* [`shellhelper_vagrant_repository_key_url`](#-gitlabrunner--shellhelper_vagrant_repository_key_url)
* [`shellhelper_virtualbox_package_version`](#-gitlabrunner--shellhelper_virtualbox_package_version)
* [`shellhelper_rbenv_sources`](#-gitlabrunner--shellhelper_rbenv_sources)
* [`shellhelper_rbenv_tag`](#-gitlabrunner--shellhelper_rbenv_tag)
* [`shellhelper_rubybuild_sources`](#-gitlabrunner--shellhelper_rubybuild_sources)
* [`shellhelper_rubybuild_tag`](#-gitlabrunner--shellhelper_rubybuild_tag)
* [`shellhelper_ruby_versions`](#-gitlabrunner--shellhelper_ruby_versions)

##### <a name="-gitlabrunner--runners"></a>`runners`

Data type: `Hash[String,Hash]`

List of runners with their settings.
Managed options of runner are :
  * limit (Integrer)
  * executor (Enum['docker','shell'])
  * executor-options (Hash with any executor option, only docker for this module version)

Default value: `{}`

##### <a name="-gitlabrunner--ensure"></a>`ensure`

Data type: `Variant[Enum['latest','present'], Pattern['^\d+\.\d+\.\d+$']]`



Default value: `'present'`

##### <a name="-gitlabrunner--package_name"></a>`package_name`

Data type: `String[1]`



Default value: `'gitlab-runner'`

##### <a name="-gitlabrunner--repository_key_id"></a>`repository_key_id`

Data type: `String`



Default value: `'F6403F6544A38863DAA0B6E03F01618A51312F3F'`

##### <a name="-gitlabrunner--repository_key_url"></a>`repository_key_url`

Data type: `Stdlib::HTTPUrl`



Default value: `'https://packages.gitlab.com/runner/gitlab-runner/gpgkey'`

##### <a name="-gitlabrunner--concurrent"></a>`concurrent`

Data type: `Integer`

Limits how many jobs globally can be run concurrently. The most upper limit of jobs using all defined runners. 0 does not mean unlimited

Default value: `4`

##### <a name="-gitlabrunner--check_resolver"></a>`check_resolver`

Data type: `Boolean`

With hosts running systemd-resolved, it ensure to not use local DNS stub on IP address 127.0.0.53

Default value: `true`

##### <a name="-gitlabrunner--dockerhelper_install_docker"></a>`dockerhelper_install_docker`

Data type: `Boolean`

This boolean defined if the docker helper installs Docker CE on runner box.

Default value: `false`

##### <a name="-gitlabrunner--dockerhelper_enable_usernamespace"></a>`dockerhelper_enable_usernamespace`

Data type: `Boolean`

With true, Docker engine is launched with user name space enable (install_docker have to be true).

Default value: `false`

##### <a name="-gitlabrunner--dockerhelper_enable_ipv6"></a>`dockerhelper_enable_ipv6`

Data type: `Boolean`

With true, Enables ipv6 support for the Docker daemon.

Default value: `true`

##### <a name="-gitlabrunner--dockerhelper_ipv6_cidr"></a>`dockerhelper_ipv6_cidr`

Data type: `Stdlib::IP::Address::V6::CIDR`

With dockerhelper_enable_ipv6 true, IPv6 subnet for fixed IPs in containers.

Default value: `'2001:db8:1::/64'`

##### <a name="-gitlabrunner--dockerhelper_prune_weekday"></a>`dockerhelper_prune_weekday`

Data type: `String[1]`

The weekday on which to run the docker prune.
Day ranges can only be numeric; e.g. '1-5' for weekdays, but not 'Mon-Fri'.

Default value: `'5'`

##### <a name="-gitlabrunner--dockerhelper_prune_hour"></a>`dockerhelper_prune_hour`

Data type: `String[1]`

The hour at which to run the docker prune.

Default value: `'3'`

##### <a name="-gitlabrunner--shellhelper_install_ruby"></a>`shellhelper_install_ruby`

Data type: `Boolean`

This boolean define if the shell helper installs Ruby on the runner box (used with shell executor).

Default value: `false`

##### <a name="-gitlabrunner--shellhelper_install_vagrant"></a>`shellhelper_install_vagrant`

Data type: `Boolean`

This boolean define if the shell helper installs Vagrant on the runner box (used with shell executor).

Default value: `false`

##### <a name="-gitlabrunner--shellhelper_install_virtualbox"></a>`shellhelper_install_virtualbox`

Data type: `Boolean`

This boolean define if the shell helper installs Virtualbox on the runner box (used with shell executor).

Default value: `false`

##### <a name="-gitlabrunner--shellhelper_vagrant_package_name"></a>`shellhelper_vagrant_package_name`

Data type: `String[1]`

The Vagrant package name installed by shell helper.

Default value: `'vagrant'`

##### <a name="-gitlabrunner--shellhelper_vagrant_package_version"></a>`shellhelper_vagrant_package_version`

Data type: `String[1]`

The Vagrant package version installed by shell helper.

Default value: `'2.4.1-1'`

##### <a name="-gitlabrunner--shellhelper_vagrant_repository_key_id"></a>`shellhelper_vagrant_repository_key_id`

Data type: `String[1]`

Specifies Hashicorp GPG key to authenticate Apt package signatures

Default value: `'798AEC654E5C15428C8E42EEAA16FCBCA621E701'`

##### <a name="-gitlabrunner--shellhelper_vagrant_repository_key_url"></a>`shellhelper_vagrant_repository_key_url`

Data type: `Stdlib::HTTPUrl`

Specifies the location of Hashicorp GPG key file to install.

Default value: `'https://apt.releases.hashicorp.com/gpg'`

##### <a name="-gitlabrunner--shellhelper_virtualbox_package_version"></a>`shellhelper_virtualbox_package_version`

Data type: `String[1]`

The VirtualBox package version installed by shell helper.

Default value: `'6.0'`

##### <a name="-gitlabrunner--shellhelper_rbenv_sources"></a>`shellhelper_rbenv_sources`

Data type: `String[1]`

The URL used to get Rbenv.

Default value: `'https://github.com/rbenv/rbenv.git'`

##### <a name="-gitlabrunner--shellhelper_rbenv_tag"></a>`shellhelper_rbenv_tag`

Data type: `String[1]`

The tag of Rbenv installed by shell helper.

Default value: `'v1.2.0'`

##### <a name="-gitlabrunner--shellhelper_rubybuild_sources"></a>`shellhelper_rubybuild_sources`

Data type: `String[1]`

The URL used to get Ruby Build

Default value: `'https://github.com/rbenv/ruby-build.git'`

##### <a name="-gitlabrunner--shellhelper_rubybuild_tag"></a>`shellhelper_rubybuild_tag`

Data type: `String[1]`

The tag of Ruby Build installed by shell helper.

Default value: `'v20240517'`

##### <a name="-gitlabrunner--shellhelper_ruby_versions"></a>`shellhelper_ruby_versions`

Data type: `Array[String[1]]`

The list of Ruby versions installed by shell helper.

Default value: `['2.7.5']`

### <a name="gitlabrunner--helper--docker"></a>`gitlabrunner::helper::docker`

Install Docker CE

#### Parameters

The following parameters are available in the `gitlabrunner::helper::docker` class:

* [`install_docker`](#-gitlabrunner--helper--docker--install_docker)
* [`runner_account`](#-gitlabrunner--helper--docker--runner_account)
* [`enable_docker_usernamespace`](#-gitlabrunner--helper--docker--enable_docker_usernamespace)
* [`enable_docker_ipv6`](#-gitlabrunner--helper--docker--enable_docker_ipv6)
* [`ipv6_cidr`](#-gitlabrunner--helper--docker--ipv6_cidr)
* [`prune_weekday`](#-gitlabrunner--helper--docker--prune_weekday)
* [`prune_hour`](#-gitlabrunner--helper--docker--prune_hour)

##### <a name="-gitlabrunner--helper--docker--install_docker"></a>`install_docker`

Data type: `Boolean`

This boolean at true the module install Docker CE on runner box.

##### <a name="-gitlabrunner--helper--docker--runner_account"></a>`runner_account`

Data type: `String`

System user account granted to use Docker engine.

##### <a name="-gitlabrunner--helper--docker--enable_docker_usernamespace"></a>`enable_docker_usernamespace`

Data type: `Boolean`

With true, Docker engine is launched with user name space enable.

##### <a name="-gitlabrunner--helper--docker--enable_docker_ipv6"></a>`enable_docker_ipv6`

Data type: `Boolean`

With true, Enables ipv6 support for the docker daemon.

##### <a name="-gitlabrunner--helper--docker--ipv6_cidr"></a>`ipv6_cidr`

Data type: `Stdlib::IP::Address::V6::CIDR`

With enable_docker_ipv6 true, IPv6 subnet for fixed IPs in containers.

##### <a name="-gitlabrunner--helper--docker--prune_weekday"></a>`prune_weekday`

Data type: `String`

The weekday on which the prune takes place

##### <a name="-gitlabrunner--helper--docker--prune_hour"></a>`prune_hour`

Data type: `String`

The hour of day on which the prune takes place

### <a name="gitlabrunner--helper--shell"></a>`gitlabrunner::helper::shell`

Install Vagrant, Virtualbox used with shell executor for acceptance tests of Puppet modules.

#### Parameters

The following parameters are available in the `gitlabrunner::helper::shell` class:

* [`install_ruby`](#-gitlabrunner--helper--shell--install_ruby)
* [`install_vagrant`](#-gitlabrunner--helper--shell--install_vagrant)
* [`install_virtualbox`](#-gitlabrunner--helper--shell--install_virtualbox)
* [`runner_account`](#-gitlabrunner--helper--shell--runner_account)
* [`vagrant_package_name`](#-gitlabrunner--helper--shell--vagrant_package_name)
* [`vagrant_package_version`](#-gitlabrunner--helper--shell--vagrant_package_version)
* [`vagrant_repository_key_id`](#-gitlabrunner--helper--shell--vagrant_repository_key_id)
* [`vagrant_repository_key_url`](#-gitlabrunner--helper--shell--vagrant_repository_key_url)
* [`virtualbox_package_version`](#-gitlabrunner--helper--shell--virtualbox_package_version)
* [`rbenv_sources`](#-gitlabrunner--helper--shell--rbenv_sources)
* [`rbenv_tag`](#-gitlabrunner--helper--shell--rbenv_tag)
* [`rubybuild_sources`](#-gitlabrunner--helper--shell--rubybuild_sources)
* [`rubybuild_tag`](#-gitlabrunner--helper--shell--rubybuild_tag)
* [`ruby_versions`](#-gitlabrunner--helper--shell--ruby_versions)

##### <a name="-gitlabrunner--helper--shell--install_ruby"></a>`install_ruby`

Data type: `Boolean`

This boolean at true the module install Ruby on the runner box (used with shell executor during puppet testing).

##### <a name="-gitlabrunner--helper--shell--install_vagrant"></a>`install_vagrant`

Data type: `Boolean`

This boolean at true the module install Vagrant on the runner box (used with shell executor during puppet testing, hypervisor=vagrant).

##### <a name="-gitlabrunner--helper--shell--install_virtualbox"></a>`install_virtualbox`

Data type: `Boolean`

This boolean at true the module install Virtualbox on the runner box (used with shell executor during puppet testing).

##### <a name="-gitlabrunner--helper--shell--runner_account"></a>`runner_account`

Data type: `String`

System user account granted to use Docker engine.

##### <a name="-gitlabrunner--helper--shell--vagrant_package_name"></a>`vagrant_package_name`

Data type: `String[1]`

The Vagrant package name installed by shell helper.

##### <a name="-gitlabrunner--helper--shell--vagrant_package_version"></a>`vagrant_package_version`

Data type: `String[1]`

The Vagrant package version installed by shell helper.

##### <a name="-gitlabrunner--helper--shell--vagrant_repository_key_id"></a>`vagrant_repository_key_id`

Data type: `String[1]`

Specifies Hashicorp GPG key to authenticate Apt package signatures

##### <a name="-gitlabrunner--helper--shell--vagrant_repository_key_url"></a>`vagrant_repository_key_url`

Data type: `Stdlib::HTTPUrl`

Specifies the location of Hashicorp GPG key file to install.

##### <a name="-gitlabrunner--helper--shell--virtualbox_package_version"></a>`virtualbox_package_version`

Data type: `String[1]`

The VirtualBox package version installed by shell helper.

##### <a name="-gitlabrunner--helper--shell--rbenv_sources"></a>`rbenv_sources`

Data type: `String[1]`

The URL used to get Rbenv.

##### <a name="-gitlabrunner--helper--shell--rbenv_tag"></a>`rbenv_tag`

Data type: `String[1]`

The tag of Rbenv installed by shell helper.

##### <a name="-gitlabrunner--helper--shell--rubybuild_sources"></a>`rubybuild_sources`

Data type: `String[1]`

The URL used to get Ruby Build

##### <a name="-gitlabrunner--helper--shell--rubybuild_tag"></a>`rubybuild_tag`

Data type: `String[1]`

The tag of Ruby Build installed by shell helper.

##### <a name="-gitlabrunner--helper--shell--ruby_versions"></a>`ruby_versions`

Data type: `Array[String[1]]`

The list of Ruby versions installed by shell helper.

## Defined types

### <a name="gitlabrunner--register"></a>`gitlabrunner::register`

Register a runner to a gitlab-ci coordinator

#### Parameters

The following parameters are available in the `gitlabrunner::register` defined type:

* [`authentication_token`](#-gitlabrunner--register--authentication_token)
* [`executor`](#-gitlabrunner--register--executor)
* [`coordinator_url`](#-gitlabrunner--register--coordinator_url)
* [`executor_options`](#-gitlabrunner--register--executor_options)
* [`limit`](#-gitlabrunner--register--limit)

##### <a name="-gitlabrunner--register--authentication_token"></a>`authentication_token`

Data type: `String`

Runner's authentication token

##### <a name="-gitlabrunner--register--executor"></a>`executor`

Data type: `Enum['docker','shell']`

Select executor used by this runner.

##### <a name="-gitlabrunner--register--coordinator_url"></a>`coordinator_url`

Data type: `Stdlib::HTTPSUrl`

Gitlab-ci coordinator url

##### <a name="-gitlabrunner--register--executor_options"></a>`executor_options`

Data type: `Optional[Variant[Hash,String]]`

List of options to use by the runner with its executor. List of available options : gitlab-runner register --help
With executor 'shell', only one option is accepted : 'bash' as String data type.

Default value: `undef`

##### <a name="-gitlabrunner--register--limit"></a>`limit`

Data type: `Integer`

Maximum number of builds processed by this runner.

Default value: `0`

### <a name="gitlabrunner--unregister"></a>`gitlabrunner::unregister`

To unregister a runner from a gitlab-ci coordinator

#### Examples

##### :

```puppet

gitlabrunner::unregister { 'runnername' : }
```

## Data types

### <a name="Gitlabrunner--Settings"></a>`Gitlabrunner::Settings`

Settings available for a runner

Alias of

```puppet
Struct[{
  'authentication-token' => String[1],
  'url'                  => Stdlib::HTTPSUrl,
  'limit'                => Optional[Integer],
  'executor'             => Enum['docker','shell'],
  'executor-options'     => Optional[Variant[Hash,String]],
}]
```

